const dns2 = require('dns2');
const superagent = require('superagent');
const environment = require('./environment');

class Helper{

    static async isIpAddress(ip){
        const regex_ip = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
        let m2 = regex_ip.exec(ip);
        return (m2 !== null);
    }

    static async isHostResolvable(host){
        const dns = new dns2({
            nameServers: [environment.nameserver]
        });

        const result = await dns.resolveA(host);
        return (result.answers.length > 0) ? result.answers[0].address : false;
    }

    static async getHostProtocol(host){
        return new Promise((resolve, reject) => {
            superagent.get('https://' + host)
                .set('User-Agent', "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/112.0")
                .send()
                .redirects(0)
                .then((res, err) => {
                    if(res.statusCode === 200){
                        resolve('https');
                    }else{
                        resolve('http');
                    }
                }).catch((err) => {
                    if(err.status === 302 || err.status === 301){
                        resolve('https');
                    }else{
                        reject(err);
                    }
            });
        });
    }
}

module.exports = Helper;
